@@ -4,6 +4,7 @@
 #' 
 #' @param mod input model object as returned by \code{\link{anlz_gam}}
 #' @param ylab chr string for y-axis label
+#' @param yromit optional numeric vector for years to omit from the plot, see details
 #' @param alpha numeric from 0 to 1 indicating line transparency
 #' @param base_size numeric indicating base font size, passed to \code{\link[ggplot2]{theme_bw}}
 #' @param xlim optional numeric vector of length two for x-axis limits
@@ -13,6 +14,9 @@
 #' @return A \code{\link[ggplot2]{ggplot}} object
 #' @export
 #' 
+#' @details
+#' The optional \code{yromit} vector can be used to omit years from the plot. This may be preferred if the predicted values from the model deviate substantially from other years likely due to missing data.
+#' 
 #' @concept show
 #' 
 #' @examples
@@ -26,11 +30,14 @@
 #' mod <- anlz_gam(tomod, trans = 'log10')
 #' 
 #' show_prdseries(mod, ylab = 'Chlorophyll-a (ug/L)')
-show_prdseries <- function(mod, ylab, alpha = 0.7, base_size = 11, xlim = NULL, ylim = NULL, col = 'brown'){
+show_prdseries <- function(mod, ylab, yromit = NULL, alpha = 0.7, base_size = 11, xlim = NULL, ylim = NULL, col = 'brown'){
 
   # get predictions
   prds <- anlz_prd(mod)
   
+  if(!is.null(yromit))
+    prds <- prds[!prds$yr %in% yromit, ]
+  
   # get transformation
   trans <- unique(prds$trans)
 
