@@ -5,6 +5,7 @@
 #' @param mod input model object as returned by \code{\link{anlz_gam}}
 #' @param doystr numeric indicating start Julian day for extracting averages
 #' @param doyend numeric indicating ending Julian day for extracting averages
+#' @param yromit optional numeric vector for years to omit from the plot, see details
 #' @param justify chr string indicating the justification for the trend window
 #' @param win numeric vector indicating number of years to use for the trend window
 #' @param txtsz numeric for size of text labels inside the plot
@@ -18,6 +19,8 @@
 #'
 #' @details This function plots output from \code{\link{anlz_sumtrndseason}}.
 #' 
+#' The optional \code{yromit} vector can be used to omit years from the plot and trend assessment. This may be preferred if seasonal estimates for a given year have very wide confidence intervals likely due to limited data, which can skew the trend assessments.
+#' 
 #' @family show
 #' 
 #' @examples
@@ -31,7 +34,8 @@
 #'
 #' mod <- anlz_gam(tomod, trans = 'log10')
 #' show_sumtrndseason(mod, doystr = 90, doyend = 180, justify = 'center', win = 2:3)
-show_sumtrndseason <- function(mod, doystr = 1, doyend = 364, justify = c('center', 'left', 'right'), 
+show_sumtrndseason <- function(mod, doystr = 1, doyend = 364, yromit = NULL, 
+                              justify = c('center', 'left', 'right'), 
                               win = 5:15, txtsz = 6, cols = c('lightblue', 'lightgreen'), 
                               base_size = 11){
   
@@ -41,7 +45,7 @@ show_sumtrndseason <- function(mod, doystr = 1, doyend = 364, justify = c('cente
   sig_vals <- c(-Inf, 0.005, 0.05, Inf)
   
   # get ests across all window widths
-  res <- anlz_sumtrndseason(mod, doystr = doystr, doyend = doyend, justify = justify, win = win)
+  res <- anlz_sumtrndseason(mod, doystr = doystr, doyend = doyend, justify = justify, win = win, yromit = yromit)
   
   # seasonal range for title
   dts <- as.Date(c(doystr, doyend), origin = as.Date("2000-12-31"))
@@ -66,8 +70,8 @@ show_sumtrndseason <- function(mod, doystr = 1, doyend = 364, justify = c('cente
     )
   
   p <- ggplot2::ggplot(toplo, ggplot2::aes(x = yr, y = win, fill = yrcoef)) +
-    ggplot2::geom_tile(color = 'black') + 
-    ggplot2::geom_text(ggplot2::aes(label = psig), size = txtsz) + 
+    ggplot2::geom_tile(color = 'black', na.rm = TRUE) + 
+    ggplot2::geom_text(ggplot2::aes(label = psig), size = txtsz, na.rm = TRUE) + 
     ggplot2::scale_x_continuous(expand = c(0, 0)) + 
     ggplot2::scale_y_continuous(expand = c(0, 0), breaks = win) +
     ggplot2::scale_fill_gradient2(low = cols[1], mid = 'white', high = cols[2], midpoint = 0) +
