@@ -6,14 +6,6 @@ test_that("Checking show_trndseason class", {
   
 })
 
-test_that("Checking show_trndseason class, usearrow as T", {
-  
-  result <- show_trndseason(mod, doystr = 90, doyend = 180, justify = 'left', win = 5, ylab = 'Slope chlorophyll-a (ug/L)', usearrow = T)
-  
-  expect_is(result, 'ggplot')
-  
-})
-
 test_that("Checking show_trndseason class, type = approx", {
   
   result <- show_trndseason(mod, doystr = 90, doyend = 180, type = 'approx', justify = 'left', win = 5, ylab = 'Slope chlorophyll-a (ug/L)')
@@ -28,4 +20,10 @@ test_that("Checking show_trndseason class, model ident", {
   
   expect_is(result, 'ggplot')
   
-})
\ No newline at end of file
+})
+
+test_that("Checking show_trndseason nms inputs", {
+  
+  expect_error(show_trndseason(modident, doystr = 90, doyend = 180, justify = 'left', win = 5, ylab = 'Slope chlorophyll-a (ug/L)', nms = 'error'), 'Three names, fills, or colors must be provided')
+  
+})
